@@ -56,6 +56,20 @@ def decimal(value):
         raise ValueError('Could not unpack data')
 
 
+def double(value):
+    """Decode a double value
+
+    :param str value: Value to decode
+    :return tuple: bytes used, float
+    :raises: ValueError
+
+    """
+    try:
+        return 8, struct.unpack_from('>d', value)[0]
+    except TypeError:
+        raise ValueError('Could not unpack data')
+
+
 def floating_point(value):
     """Decode a floating point value
 
@@ -243,6 +257,8 @@ def _embedded_value(value):
     # Determine the field type and encode it
     if value[0] == 'A':
         bytes_consumed, value = field_array(value[1:])
+    elif value[0] == 'd':
+        bytes_consumed, value = double(value[1:])
     elif value[0] == 'D':
         bytes_consumed, value = decimal(value[1:])
     elif value[0] == 'f':
@@ -290,6 +306,8 @@ def by_type(value, data_type, offset=0):
         return boolean(value)
     elif data_type == 'decimal':
         return decimal(value)
+    elif data_type == 'double':
+        return double(value)
     elif data_type == 'float':
         return floating_point(value)
     elif data_type == 'long':
@@ -319,6 +337,7 @@ METHODS = {'array': field_array,
            'bit': bit,
            'boolen': boolean,
            'decimal': decimal,
+           'double': double,
            'float': floating_point,
            'long': long_int,
            'longlong': long_long_int,
